The following commit has been merged in the master branch:
commit d14c72ffee3ffd98b8ecb0b189f197b404b56a9e
Author: Guillem Jover <guil...@debian.org>
Date:   Fri Apr 29 07:20:53 2011 +0200

    libdpkg: Move version module declarations to a new version.h

diff --git a/lib/dpkg/Makefile.am b/lib/dpkg/Makefile.am
index 59f7d52..04c4be9 100644
--- a/lib/dpkg/Makefile.am
+++ b/lib/dpkg/Makefile.am
@@ -98,4 +98,5 @@ pkginclude_HEADERS = \
        tarfn.h \
        trigdeferred.h \
        triglib.h \
-       varbuf.h
+       varbuf.h \
+       version.h
diff --git a/lib/dpkg/dpkg-db.h b/lib/dpkg/dpkg-db.h
index 952fee5..86b2490 100644
--- a/lib/dpkg/dpkg-db.h
+++ b/lib/dpkg/dpkg-db.h
@@ -29,15 +29,10 @@
 
 #include <dpkg/macros.h>
 #include <dpkg/varbuf.h>
+#include <dpkg/version.h>
 
 DPKG_BEGIN_DECLS
 
-struct versionrevision {
-  unsigned long epoch;
-  const char *version;
-  const char *revision;
-};
-
 enum deptype {
   dep_suggests,
   dep_recommends,
@@ -244,7 +239,6 @@ void modstatdb_shutdown(void);
 
 void pkg_blank(struct pkginfo *pp);
 void pkgbin_blank(struct pkgbin *pifp);
-void blankversion(struct versionrevision*);
 bool pkg_is_informative(struct pkginfo *pkg, struct pkgbin *info);
 
 struct pkginfo *pkg_db_find(const char *name);
diff --git a/lib/dpkg/version.c b/lib/dpkg/version.c
index c7d8f68..9e7cc82 100644
--- a/lib/dpkg/version.c
+++ b/lib/dpkg/version.c
@@ -21,7 +21,7 @@
 #include <config.h>
 #include <compat.h>
 
-#include <dpkg/dpkg-db.h>
+#include <dpkg/version.h>
 
 void
 blankversion(struct versionrevision *version)
diff --git a/lib/dpkg/dir.h b/lib/dpkg/version.h
similarity index 69%
copy from lib/dpkg/dir.h
copy to lib/dpkg/version.h
index ad8fa83..3eb70f1 100644
--- a/lib/dpkg/dir.h
+++ b/lib/dpkg/version.h
@@ -1,8 +1,8 @@
 /*
  * libdpkg - Debian packaging suite library routines
  * dir.h - directory handling routines
  *
- * Copyright © 2010 Guillem Jover <guil...@debian.org>
+ * Copyright © 1994,1995 Ian Jackson <i...@chiark.greenend.org.uk>
  *
  * This is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,19 +18,21 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef LIBDPKG_DIR_H
-#define LIBDPKG_DIR_H
+#ifndef LIBDPKG_VERSION_H
+#define LIBDPKG_VERSION_H
 
 #include <dpkg/macros.h>
 
-#include <dirent.h>
-
 DPKG_BEGIN_DECLS
 
-void dir_sync_path(const char *path);
-void dir_sync_path_parent(const char *path);
-void dir_sync_contents(const char *path);
+struct versionrevision {
+       unsigned long epoch;
+       const char *version;
+       const char *revision;
+};
+
+void blankversion(struct versionrevision *version);
 
 DPKG_END_DECLS
 
-#endif /* LIBDPKG_DIR_H */
+#endif /* LIBDPKG_VERSION_H */
@@ -1,8 +1,8 @@
 /*
  * libdpkg - Debian packaging suite library routines
- * dir.h - directory handling routines
+ * version.h - version handling routines
  *

-- 
dpkg's main repository


-- 
To UNSUBSCRIBE, email to debian-dpkg-cvs-requ...@lists.debian.org
with a subject of "unsubscribe". Trouble? Contact listmas...@lists.debian.org

Reply via email to